@@ -51,7 +51,7 @@ class BoundedIntStrategy(SearchStrategy):
         self.end = end
 
     def __repr__(self):
-        return "BoundedIntStrategy(%d, %d)" % (self.start, self.end)
+        return f"BoundedIntStrategy({self.start}, {self.end})"
 
     def do_draw(self, data):
         return d.integer_range(data, self.start, self.end)
@@ -161,10 +161,8 @@ class FixedBoundedFloatStrategy(SearchStrategy):
         self.width = width
 
     def __repr__(self):
-        return "FixedBoundedFloatStrategy(%s, %s, %s)" % (
-            self.lower_bound,
-            self.upper_bound,
-            self.width,
+        return "FixedBoundedFloatStrategy({}, {}, {})".format(
+            self.lower_bound, self.upper_bound, self.width
         )
 
     def do_draw(self, data):
